Re: [sugar] [PATCH 1/2] Add is_modifier and is_special_modifier functions to SugarKeyGrabber.

2008-06-20 Thread Marco Pesenti Gritti
On Thu, Jun 19, 2008 at 9:06 PM, Benjamin Berg
[EMAIL PROTECTED] wrote:
 +   modmap = XGetModifierMapping (xdisplay);

No space between function name and (

 +gboolean sugar_key_grabber_is_modifier  (SugarKeyGrabber *grabber,
 + guintkeycode);
 +gboolean sugar_key_grabber_is_specific_modifier (SugarKeyGrabber *grabber,
 + guintkeycode,
 + guintmask);
 +

What about collapsing this in a single function and making it look
like this in python:

key_grabber.is_modifier(keycode, mask=-1)

You can do that in the bindings with something like this:

(define-method set
  (of-object GtkAspectFrame)
  (c-name gtk_aspect_frame_set)
  (return-type none)
  (parameters
'(gfloat xalign (default 0.0))
'(gfloat yalign (default 0.0))
'(gfloat ratio (default 1.0))
'(gboolean obey_child (default 1))
  )
)

r+ with those changes.

Marco
___
Sugar mailing list
Sugar@lists.laptop.org
http://lists.laptop.org/listinfo/sugar


Re: [sugar] [PATCH 2/2] Add scroll_to_item functions to the trays to show a button that may be hidden.

2008-06-20 Thread Marco Pesenti Gritti
r+

On Thu, Jun 19, 2008 at 9:07 PM, Benjamin Berg
[EMAIL PROTECTED] wrote:

 ---

  src/sugar/graphics/tray.py |   25 +
  1 files changed, 25 insertions(+), 0 deletions(-)

 diff --git a/src/sugar/graphics/tray.py b/src/sugar/graphics/tray.py
 index d7d5918..2f5db9a 100644
 --- a/src/sugar/graphics/tray.py
 +++ b/src/sugar/graphics/tray.py
 @@ -67,6 +67,25 @@ class _TrayViewport(gtk.Viewport):
 elif direction == _NEXT_PAGE:
 self._scroll_next()

 +def scroll_to_item(self, item):
 +This function scrolls the viewport so that item will be 
 visible.
 +assert item in self.traybar.get_children()
 +
 +# Get the allocation, and make sure that it is visible
 +if self.orientation == gtk.ORIENTATION_HORIZONTAL:
 +adj = self.get_hadjustment()
 +start = item.allocation.x
 +stop = item.allocation.x + item.allocation.width
 +else:
 +adj = self.get_vadjustment()
 +start = item.allocation.y
 +stop = item.allocation.y + item.allocation.height
 +
 +if start  adj.value:
 +adj.value = start
 +elif stop  adj.value + adj.page_size:
 +adj.value = stop - adj.page_size
 +
 def _scroll_next(self):
 allocation = self.get_allocation()
 if self.orientation == gtk.ORIENTATION_HORIZONTAL:
 @@ -218,6 +237,9 @@ class HTray(gtk.HBox):
 def get_item_index(self, item):
 return self._viewport.traybar.get_item_index(item)

 +def scroll_to_item(self, item):
 +self._viewport.scroll_to_item(item)
 +
  class VTray(gtk.VBox):
 def __init__(self, **kwargs):
 gobject.GObject.__init__(self, **kwargs)
 @@ -249,6 +271,9 @@ class VTray(gtk.VBox):
 def get_item_index(self, item):
 return self._viewport.traybar.get_item_index(item)

 +def scroll_to_item(self, item):
 +self._viewport.scroll_to_item(item)
 +
  class TrayButton(ToolButton):
 def __init__(self, **kwargs):
 ToolButton.__init__(self, **kwargs)

 ___
 Sugar mailing list
 Sugar@lists.laptop.org
 http://lists.laptop.org/listinfo/sugar

___
Sugar mailing list
Sugar@lists.laptop.org
http://lists.laptop.org/listinfo/sugar


Re: [sugar] [PATCH 1/6] Add functionallity for tabbing trough activities.

2008-06-20 Thread Marco Pesenti Gritti
I would just add a set_tabbing_activity method. No tabbing activity
(None) means that no tabbing is in progress.

r+ with this change

Marco

On Thu, Jun 19, 2008 at 9:08 PM, Benjamin Berg
[EMAIL PROTECTED] wrote:
 To be able to raise activity windows on a delay, the homemodel needs to
 be set directly. It also needs to ignore window raises while the user is
 tabbing.
 ---

  src/model/homemodel.py |   15 +++
  1 files changed, 15 insertions(+), 0 deletions(-)

 diff --git a/src/model/homemodel.py b/src/model/homemodel.py
 index a75adcf..be46ffb 100644
 --- a/src/model/homemodel.py
 +++ b/src/model/homemodel.py
 @@ -64,6 +64,7 @@ class HomeModel(gobject.GObject):

 self._activities = []
 self._active_activity = None
 +self._tabbing = False

 screen = wnck.screen_get_default()
 screen.connect('window-opened', self._window_opened_cb)
 @@ -102,6 +103,15 @@ class HomeModel(gobject.GObject):
 Returns the activity that the user is currently working in
 return self._active_activity

 +def tabbing_set_activity(self, activity):
 +self._set_active_activity(activity)
 +
 +def tabbing_start(self):
 +self._tabbing = True
 +
 +def tabbing_stop(self):
 +self._tabbing = False
 +
 def _set_active_activity(self, home_activity):
 if self._active_activity == home_activity:
 return
 @@ -185,6 +195,11 @@ class HomeModel(gobject.GObject):
 logging.error(set_active() failed: %s % err)

 def _active_window_changed_cb(self, screen, previous_window=None):
 +if self._tabbing:
 +# Ignore any window changes when tabbing, as these are comming
 +# in delayed.
 +return
 +
 window = screen.get_active_window()
 if window is None:
 return

 ___
 Sugar mailing list
 Sugar@lists.laptop.org
 http://lists.laptop.org/listinfo/sugar

___
Sugar mailing list
Sugar@lists.laptop.org
http://lists.laptop.org/listinfo/sugar


Re: [sugar] [PATCH 5/6] Scroll to the button that is selected in the tabbing operation.

2008-06-20 Thread Marco Pesenti Gritti
r+

On Thu, Jun 19, 2008 at 9:11 PM, Benjamin Berg
[EMAIL PROTECTED] wrote:

 ---

  src/view/frame/activitiestray.py |2 ++
  1 files changed, 2 insertions(+), 0 deletions(-)

 diff --git a/src/view/frame/activitiestray.py 
 b/src/view/frame/activitiestray.py
 index 03a523e..c34c119 100644
 --- a/src/view/frame/activitiestray.py
 +++ b/src/view/frame/activitiestray.py
 @@ -342,6 +342,8 @@ class ActivitiesTray(HTray):
 self._freeze_button_clicks = True
 button.props.active = True
 self._freeze_button_clicks = True
 +
 +self.scroll_to_item(button)

 def __activity_clicked_cb(self, button, home_activity):
 if not self._freeze_button_clicks and button.props.active:

 ___
 Sugar mailing list
 Sugar@lists.laptop.org
 http://lists.laptop.org/listinfo/sugar

___
Sugar mailing list
Sugar@lists.laptop.org
http://lists.laptop.org/listinfo/sugar


Re: [sugar] [PATCH 6/6] Use Alt+Tab for reverse tabbing direction

2008-06-20 Thread Marco Pesenti Gritti
r+

On Thu, Jun 19, 2008 at 9:11 PM, Benjamin Berg
[EMAIL PROTECTED] wrote:

 ---

  src/view/keyhandler.py |2 +-
  1 files changed, 1 insertions(+), 1 deletions(-)

 diff --git a/src/view/keyhandler.py b/src/view/keyhandler.py
 index b42b93c..ab779ec 100644
 --- a/src/view/keyhandler.py
 +++ b/src/view/keyhandler.py
 @@ -59,7 +59,7 @@ _actions_table = {
 'altq' : 'quit_emulator',
 'altTab'   : 'next_window',
 'altn' : 'next_window',
 -'ctrlaltTab' : 'previous_window',
 +'altshiftTab': 'previous_window',
 'altp' : 'previous_window',
 'ctrlEscape'   : 'close_window',
 'ctrlq': 'close_window',

 ___
 Sugar mailing list
 Sugar@lists.laptop.org
 http://lists.laptop.org/listinfo/sugar

___
Sugar mailing list
Sugar@lists.laptop.org
http://lists.laptop.org/listinfo/sugar


Re: [sugar] [PATCH 3/6] Handle the keyboard event handling for tabbing.

2008-06-20 Thread Marco Pesenti Gritti
On Thu, Jun 19, 2008 at 9:09 PM, Benjamin Berg
[EMAIL PROTECTED] wrote:
 +# The modifier used for tabbing. Should the shortcuts ever be made user
 +# configurable, then some code to figure out the apropriate modifier is
 +# needed instead of hardcoding it.

I'd remove this comment. Seem implicit in the fact that you defined it as a var.
I'd prefer if this was factored out to TabbingHandler along with the shell.

Marco
___
Sugar mailing list
Sugar@lists.laptop.org
http://lists.laptop.org/listinfo/sugar


Re: [sugar] [PATCH 2/6] Implement API to handle tabbing.

2008-06-20 Thread Marco Pesenti Gritti
On Thu, Jun 19, 2008 at 9:08 PM, Benjamin Berg
[EMAIL PROTECTED] wrote:
 +def tabbing_activate_current(self):
 +home_model = self._model.get_home()
 +activity = home_model.get_active_activity()
 +if activity and activity.get_window():
 +activity.get_window().activate(1)

Do we get a window_changed even in the model even if the window has
really been activated during the tabbing?

Marco
___
Sugar mailing list
Sugar@lists.laptop.org
http://lists.laptop.org/listinfo/sugar


Re: [sugar] [PATCH] Add an option for choosing the layout in the favorites view.

2008-06-20 Thread Marco Pesenti Gritti
r+

On Thu, Jun 19, 2008 at 8:57 PM, Tomeu Vizoso [EMAIL PROTECTED] wrote:
 Hi,

 this patch adds an option to what used to be the Ring view palette for
 choosing the layout to use in the favorites view.

 Thanks,

 Tomeu

 ___
 Sugar mailing list
 Sugar@lists.laptop.org
 http://lists.laptop.org/listinfo/sugar


___
Sugar mailing list
Sugar@lists.laptop.org
http://lists.laptop.org/listinfo/sugar


Re: [sugar] feature freeze coming

2008-06-20 Thread Marco Pesenti Gritti
On Wed, Jun 18, 2008 at 11:18 PM, Martin Dengler
[EMAIL PROTECTED] wrote:

A couple of general comments, I just skimmed through the patches.

 - #2954 - patch Browse and Read for cursor hiding in handheld mode.
   Mature patch, the approach was verbally ok'ed by eben  bemasc and
   hasn't been shouted down by marco/tomeu recently :)
   
 http://dev.laptop.org/git?p=users/mdengler/sugar-toolkit;a=commitdiff;h=bb8f54e9bfad18699386cf814ca2c592ca0d258f

This add non-trivial public API. I think it's too late to consider it.

 - #7249 - device ordering in the Frame is not fixed.  Not submitted
   before but quite trivial to accept/reject the design.
   
 http://dev.laptop.org/git?p=users/mdengler/sugar;a=commitdiff;h=aec9692c7c3d146e512d1c873de0082b09902d7c

I think this one can land in 0.81.4.

Marco
___
Sugar mailing list
Sugar@lists.laptop.org
http://lists.laptop.org/listinfo/sugar


Re: [sugar] [PATCH 2/6] Implement API to handle tabbing.

2008-06-20 Thread Benjamin Berg
On Fri, 2008-06-20 at 11:19 +0200, Marco Pesenti Gritti wrote:
 On Thu, Jun 19, 2008 at 9:08 PM, Benjamin Berg
 [EMAIL PROTECTED] wrote:
  +def tabbing_activate_current(self):
  +home_model = self._model.get_home()
  +activity = home_model.get_active_activity()
  +if activity and activity.get_window():
  +activity.get_window().activate(1)
 
 Do we get a window_changed even in the model even if the window has
 really been activated during the tabbing?

Yes. Because of this the model needs to ignore window changes during
tabbing. If the window changes were not ignored, a race condition
exists:
 - User tabs
 - Timeout to activate the window fires
 - User tabs
 - Window is raised a bit later
 - The homemodel emits active-activity-changed

And in the end the wrong button is selected in the activities tray (for
1/4 of a second).

Benjamin




signature.asc
Description: This is a digitally signed message part
___
Sugar mailing list
Sugar@lists.laptop.org
http://lists.laptop.org/listinfo/sugar


Re: [sugar] [PATCH] Add an option for choosing the layout in the favorites view.

2008-06-20 Thread Walter Bender
Is this done in a way such that it can be set by the customization key
process? I can imagine that many groups will prefer the ring to random
and want to make it an installation default.

-walter

On Fri, Jun 20, 2008 at 5:36 AM, Marco Pesenti Gritti
[EMAIL PROTECTED] wrote:
 r+

 On Thu, Jun 19, 2008 at 8:57 PM, Tomeu Vizoso [EMAIL PROTECTED] wrote:
 Hi,

 this patch adds an option to what used to be the Ring view palette for
 choosing the layout to use in the favorites view.

 Thanks,

 Tomeu

 ___
 Sugar mailing list
 Sugar@lists.laptop.org
 http://lists.laptop.org/listinfo/sugar


 ___
 Sugar mailing list
 Sugar@lists.laptop.org
 http://lists.laptop.org/listinfo/sugar

___
Sugar mailing list
Sugar@lists.laptop.org
http://lists.laptop.org/listinfo/sugar


Re: [sugar] [PATCH] Add an option for choosing the layout in the favorites view.

2008-06-20 Thread Tomeu Vizoso
On Fri, Jun 20, 2008 at 6:08 PM, Walter Bender [EMAIL PROTECTED] wrote:
 Is this done in a way such that it can be set by the customization key
 process? I can imagine that many groups will prefer the ring to random
 and want to make it an installation default.

Not right now, but would be quite easy to add an option to the control
panel and let customization keys change the stored preference.

Tomeu
___
Sugar mailing list
Sugar@lists.laptop.org
http://lists.laptop.org/listinfo/sugar


Re: [sugar] [PATCH] Add an option for choosing the layout in the favorites view.

2008-06-20 Thread Marco Pesenti Gritti
On Fri, Jun 20, 2008 at 6:24 PM, Tomeu Vizoso [EMAIL PROTECTED] wrote:
 On Fri, Jun 20, 2008 at 6:08 PM, Walter Bender [EMAIL PROTECTED] wrote:
 Is this done in a way such that it can be set by the customization key
 process? I can imagine that many groups will prefer the ring to random
 and want to make it an installation default.

 Not right now, but would be quite easy to add an option to the control
 panel and let customization keys change the stored preference.

Even if not exposed in the cp UI we should at least have an hidden preference.
We have no way right to customize sugar profiles but we should have one.

Marco
___
Sugar mailing list
Sugar@lists.laptop.org
http://lists.laptop.org/listinfo/sugar


[sugar] Chat-41 released

2008-06-20 Thread Morgan Collett
I have released Chat 41, at the following URLs:

http://dev.laptop.org/pub/sugar/sources/chat-activity/Chat-41.tar.bz2http://dev.laptop.org/pub/sugar/sources/chat-activity/Chat-40.tar.bz2
http://dev.laptop.org/~morgan/bundles/Chat-41.xohttp://dev.laptop.org/%7Emorgan/bundles/Chat-40.xo

The changelog from Chat 40 is:

* Updated translations: mr, de, ht, km, es, it
* #6036: Add separator after old chat history (morgs)
* #6298: Implement 1-1 private chat with non Sugar Jabber clients (morgs)

Regards,
Morgan
___
Sugar mailing list
Sugar@lists.laptop.org
http://lists.laptop.org/listinfo/sugar


Re: [sugar] [Localization] Kreyòl Localization

2008-06-20 Thread Edward Cherlin
We need some help from people who know the Activities well.

On Fri, Jun 20, 2008 at 5:56 AM, Jude Augusma [EMAIL PROTECTED] wrote:
 Hi Marvin,

 I went through the 106 strings in the terminology section and all except two
 of them which I will include in my questions are easy. The terminology
 section is just regular word, I am not seeing computer programming language
 word there at all, as you can see it take me just a little while to
 translate them all.

Sayamindu generated the terminology section with a script. It actually
needs to be constructed from questions like yours, and the entries
have to provide some explanation or context. Sayamindu, how can we add
context to Pootle entries?

For the items I marked below as needing context, it will help if I
know which file they are in, so I can look for them in the
corresponding program.

 Let's take some strings I am having problem with, just some of them:

 Smalltalk code

Smalltalk is a programming language. Etoys on the XO is a teaching
environment built on the Squeak version of Smalltalk. Code is the text
of a program.

 smoothing

We need a context for this. Is it graphics or statistics or what?

 A broom to align Morphs with

This means little to me. In principle a Morph should be a shape of
some kind. If Morphs are Smalltalk objects, then they could be shapes
with methods for making variations. Aligning shapes in rows or columns
makes sense, but I would have to see this broom in the screen to have
any idea of what it is or how it works.

 A UML composite state shape
 Composite State
 UML Package

UML (Unified Modeling Language) has its own terminology. Much more
information at http://www.uml.org/

 AND Gate

In logic, an AND statement is true if and only if both components are
true. In circuitry, an AND gate has two inputs implementing that AND
logic. If we represent False by 0 and True by 1, the state table for
an AND gate is

0 0: 0 Both false, no
0 1: 0 One true, one false, no
1 0: 0 One false, one true, no
1 1: 1 Both true, yes

 Another pointing hand

A pointing hand can be any of these characters: ☚☛☜☝☞☟ (Unicode
U+261A-261F) or a graphic of similar form.

 XOR Gate

In logic, an XOR (exclusive or) statement is true if and only if the
inputs have different values. One or the other is true, but not both.
State table:
0 0: 0
0 1: 1
1 0: 1
1 1: 0

 Scrolled State

Needs context

 Squeak

A version of Smalltalk. The logo for Squeak is a mouse (rodent) face.
I think we should leave it as it is, but if it is to be translated, we
want the word for the sound a mouse makes.

 STClass
 FSM ButtonBar
 FSM Flap
 Arrow Editor
 Toggle dots
 Clear clicks

Explanation and context needed.

 A handy Morph-generating button

Handy=convenient. We had Morphs above. This is a convenient button on
the screen for generating Morphs, one per mouse click on the button.

 attachmentOwnerChanged

This seems to be a piece of program code. If so, leave it as is unless
we translate the identifiers in the program someday.

 sourceConnected
 RandomConnector

Also identifier names.

 A basic Connector that bends smoothly

In a drawing program such as Microsoft Visio, or in Free Software
Kivio, there are straight line connectors, connectors that bend at
right angles to turn corners, and smoothly curved connectors.

 flap

There are several kinds of flap in English. We need context.

Birds flap their wings
Airplanes have control flaps
Various objects have flaps that fold over

 Kedema Turtle

Kedema is part of Squeak. This seems to refer to turtle graphics, as
in the Turtle Art activity.

 Some the strings like the above, I translate them but my translation does
 not make sense to me in a computer world. For example: what is a Turtle? is
 it the animal Turtle? What is a Morph? a XOR gate, Random connector? etc.

 Marvin I will call you later today, I will not be home this morning again.

 Jude

 - Original Message 
 From: Marvin Demuth [EMAIL PROTECTED]
 To: [EMAIL PROTECTED]
 Sent: Thursday, June 19, 2008 4:28:32 PM
 Subject: [Localization] Kreyòl Localization

 At 12:33 PM 6/19/2008, Edward Cherlin wrote:

This is the reason for the Terminology section
of Pootle, for example. We encourage localizers
to do the Terminology section first, and then to
use that terminology consistently everywhere else.

 Jude, I suggest that you look again at the 106
 strings in the terminology section that remain to
 be translated, do what you can with them, and
 then let's let the list participants help with the balance.

 As others has said today, every translator faces
 this same problem, especially in those languages
 that do not have technical publications.  Ed's
 example of the lack of a word for computer in the
 Kinyarwanda language is a case in point.  We may
 have to coin some Kreyòl words.

 A journey begins with a single step. -- I can
 visualize that Samy can send the remaining words
 to the 43 professional programmers on his
 list.  Those of us who do not know Kreyòl might
 

Re: [sugar] [Localization] Kreyòl Localization

2008-06-20 Thread Bert Freudenberg
On 20.06.2008, at 19:07, Edward Cherlin wrote:

 Etoys on the XO

Anyone translating Etoys should subscribe to the Etoys list.

http://lists.laptop.org/listinfo/etoys

Etoys is more complex than all the other activities combined, and we  
are still working on improving the situation for translators (see the  
past discussions).

- Bert -


___
Sugar mailing list
Sugar@lists.laptop.org
http://lists.laptop.org/listinfo/sugar


[sugar] New release Web-91

2008-06-20 Thread Tomeu Vizoso
Hi,

several people brought cool features and new translations in this
release, you can get it at:

source: http://dev.laptop.org/pub/sugar/sources/web-activity/Web-91.tar.bz2

xo bundle: http://dev.laptop.org/~tomeu/Web-91.xo

NEWS

* Translation update for Italian (Carlo Falciola)
* Update page title when a new URI is loaded (eben)
* Clean up appearance of URI auto-completion popup (eben)
* Support certificate exceptions (marco)
* Translation update for Khmer (Rit Lim)
* Translation update for Haitian Creole (masterches)
* Reveal URI on rollover of the location bar (eben)
* Translation update for German (Markus Schlager)
* Translation update for Marathi (Sandip Gawas)

Thanks all,

Tomeu
___
Sugar mailing list
Sugar@lists.laptop.org
http://lists.laptop.org/listinfo/sugar


Re: [sugar] [Localization] Kreyòl Localization

2008-06-20 Thread Edward Cherlin
On Fri, Jun 20, 2008 at 10:16 AM, Bert Freudenberg [EMAIL PROTECTED] wrote:
 On 20.06.2008, at 19:07, Edward Cherlin wrote:

 Etoys on the XO

 Anyone translating Etoys should subscribe to the Etoys list.

 http://lists.laptop.org/listinfo/etoys

I'll add that to the Localization Wiki page. Done.

 Etoys is more complex than all the other activities combined, and we
 are still working on improving the situation for translators (see the
 past discussions).

 - Bert -


 ___
 Sugar mailing list
 Sugar@lists.laptop.org
 http://lists.laptop.org/listinfo/sugar




-- 
Edward Cherlin
End Poverty at a Profit by teaching children business
http://www.EarthTreasury.org/
The best way to predict the future is to invent it.--Alan Kay
___
Sugar mailing list
Sugar@lists.laptop.org
http://lists.laptop.org/listinfo/sugar


[sugar] sugar-datastore-0.8.2 released!

2008-06-20 Thread Tomeu Vizoso
Hi all,

a new version of the datastore has been released:

http://dev.laptop.org/pub/sugar/sources/sugar-datastore/sugar-datastore-0.8.2.tar.bz2

NEWS

Maintain a metadata copy outside the index (tomeu)

Regards,

Tomeu
___
Sugar mailing list
Sugar@lists.laptop.org
http://lists.laptop.org/listinfo/sugar


[sugar] sugar-presence-service 0.81.2 released

2008-06-20 Thread Morgan Collett
The Features on ice release.

tar:
https://dev.laptop.org/pub/sugar/sources/sugar-presence-service/sugar-presence-service-0.81.2.tar.bz2https://dev.laptop.org/pub/sugar/sources/sugar-presence-service/sugar-presence-service-0.81.1.tar.bz2


NEWS:

* add a channel type arg to the PrivateInvitation signal


Regards
Morgan
___
Sugar mailing list
Sugar@lists.laptop.org
http://lists.laptop.org/listinfo/sugar


[sugar] Journal-92 is out!

2008-06-20 Thread Tomeu Vizoso
Hi,

was just released a new version of the journal activity, with many
translation updates and some visual fixes:

http://dev.laptop.org/pub/sugar/sources/journal-activity/journal-activity-92.tar.bz2

NEWS

* Add indications for empty Journal and empty search results (eben)
* Translation update for Italian (Carlo Falciola)
* Fix appearance of no preview (eben)
* Translation update for Khmer (Rit Lim)
* Translation update for Haitian Creole (masterches)
* Translation update for German (Markus Schlager)
* Translation update for Marathi (Rupali Sarode)
* Translation update for French (Samy Boutayeb)
* Adapt object chooser to new designs. Some refactoring was needed (tomeu)
* Adapt UI to right-to-left scripts (khaled)

Cheers,

Tomeu
___
Sugar mailing list
Sugar@lists.laptop.org
http://lists.laptop.org/listinfo/sugar


[sugar] Distinguishing the text input focus

2008-06-20 Thread Mikus Grinbergs
Was playing around with the latest Journal.  It (and various other 
Activities) displays the 'text cursor' as a thin vertical line -- 
hard for my aging eyes to notice.

Accidentally clicked on the label of an entry -- that transformed 
that label field into an entry field.  But VISUALLY, there was 
little (except that thin vertical line) to draw my attention to 
*here* being where any future user-keypresses would now go.


In cyberspace, browsers have an option to color an input field 
when it has the focus.  Let me suggest that Sugar implement this -- 
for instance, put a light-yellow background on whichever text field 
has the input focus.


mikus

___
Sugar mailing list
Sugar@lists.laptop.org
http://lists.laptop.org/listinfo/sugar


[sugar] journal sort ?

2008-06-20 Thread Mikus Grinbergs
In the OLPC wiki, the HIG:Journal talks about sorting.  There has 
been a ticket open for a year about adding sorting to the Journal.

When referring to things for which when is no longer remembered, 
being able to *sort* Journal entries (e.g., by name) can help.

mikus

___
Sugar mailing list
Sugar@lists.laptop.org
http://lists.laptop.org/listinfo/sugar


[sugar] [PATCH] Remove redundant notifications from activity launch

2008-06-20 Thread Eben Eliason
---
 src/view/frame/activitiestray.py |   14 --
 1 files changed, 0 insertions(+), 14 deletions(-)

diff --git a/src/view/frame/activitiestray.py b/src/view/frame/activitiestray.py
index c34c119..801288f 100644
--- a/src/view/frame/activitiestray.py
+++ b/src/view/frame/activitiestray.py
@@ -67,26 +67,12 @@ class ActivityButton(RadioToolButton):
 self._icon.props.pulsing = True
 self._notify_launching_hid = home_activity.connect( \
 'notify::launching', self.__notify_launching_cb)
-
-self._notif_icon = NotificationIcon()
-self._notif_icon.props.xo_color = home_activity.get_icon_color()
-if home_activity.get_icon_path():
-icon_path = home_activity.get_icon_path()
-self._notif_icon.props.icon_filename = icon_path
-else:
-self._notif_icon.props.icon_name = 'image-missing'
-frame = view.frame.frame.get_instance()
-frame.add_notification(self._notif_icon, view.frame.frame.TOP_LEFT)
 else:
 self._notify_launching_hid = None
 self._notif_icon = None

 def __notify_launching_cb(self, home_activity, pspec):
 if not home_activity.props.launching:
-if self._notif_icon is not None:
-frame = view.frame.frame.get_instance()
-frame.remove_notification(self._notif_icon)
-self._notif_icon = None
 self._icon.props.pulsing = False
 home_activity.disconnect(self._notify_launching_hid)

--
___
Sugar mailing list
Sugar@lists.laptop.org
http://lists.laptop.org/listinfo/sugar


[sugar] [PATCH] Reset activity icons when clicked/launched (#7273, #7274)

2008-06-20 Thread Eben Eliason
The act of clicking on an activity icon in Home to launch it
switches the view to the launcher, eliminating the expected
hovering-changed event (leave).  This commit hides the palette
instantly (it used to remain visible in the launcher) and
un-colors the icon (which used to remain colored when returning
to Home).

---
 src/view/home/activitieslist.py |   11 ++-
 src/view/home/favoritesview.py  |8 +++-
 2 files changed, 17 insertions(+), 2 deletions(-)

diff --git a/src/view/home/activitieslist.py b/src/view/home/activitieslist.py
index 5dab09d..8086b7b 100644
--- a/src/view/home/activitieslist.py
+++ b/src/view/home/activitieslist.py
@@ -110,6 +110,9 @@ class ActivityIcon(CanvasIcon):
 fill_color=style.COLOR_TRANSPARENT.get_svg())
 self._activity_info = activity_info
 self.connect('hovering-changed', self.__hovering_changed_event_cb)
+self.connect('button-release-event', self.__button_release_event_cb)
+
+self._palette = None

 def __hovering_changed_event_cb(self, icon, event):
 if event:
@@ -118,8 +121,14 @@ class ActivityIcon(CanvasIcon):
 self.props.stroke_color = style.COLOR_BUTTON_GREY.get_svg()
 self.props.fill_color = style.COLOR_TRANSPARENT.get_svg()

+def __button_release_event_cb(self, icon, event):
+self._palette.popdown(immediate=True)
+self.props.stroke_color = style.COLOR_BUTTON_GREY.get_svg()
+self.props.fill_color = style.COLOR_TRANSPARENT.get_svg()
+
 def create_palette(self):
-return ActivityPalette(self._activity_info)
+self._palette = ActivityPalette(self._activity_info)
+return self._palette

 class ActivityEntry(hippo.CanvasBox, hippo.CanvasItem):
 __gtype_name__ = 'SugarActivityEntry'
diff --git a/src/view/home/favoritesview.py b/src/view/home/favoritesview.py
index a6e2268..6e56db5 100644
--- a/src/view/home/favoritesview.py
+++ b/src/view/home/favoritesview.py
@@ -274,8 +274,11 @@ class ActivityIcon(CanvasIcon):
 self.props.stroke_color = style.COLOR_BUTTON_GREY.get_svg()
 self.props.fill_color = style.COLOR_TRANSPARENT.get_svg()

+self._palette = None
+
 def create_palette(self):
-return ActivityPalette(self._activity_info)
+self._palette = ActivityPalette(self._activity_info)
+return self._palette

 def __hovering_changed_event_cb(self, icon, event):
 if event:
@@ -285,6 +288,9 @@ class ActivityIcon(CanvasIcon):
 self.props.fill_color = style.COLOR_TRANSPARENT.get_svg()

 def __button_release_event_cb(self, icon, event):
+self._palette.popdown(immediate=True)
+self.props.stroke_color = style.COLOR_BUTTON_GREY.get_svg()
+self.props.fill_color = style.COLOR_TRANSPARENT.get_svg()
 view.Shell.get_instance().start_activity(self._activity_info.bundle_id)

 def get_bundle_id(self):
--
___
Sugar mailing list
Sugar@lists.laptop.org
http://lists.laptop.org/listinfo/sugar


[sugar] [PATCH] Rename Free view to Freeform view, for clarity

2008-06-20 Thread Eben Eliason
This change was discussed at the design call today, and we felt it was
worth slipping in.

---
 src/view/home/HomeBox.py |4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)

diff --git a/src/view/home/HomeBox.py b/src/view/home/HomeBox.py
index 61ceee9..46d2fbc 100644
--- a/src/view/home/HomeBox.py
+++ b/src/view/home/HomeBox.py
@@ -207,8 +207,8 @@ class FavoritesButton(RadioToolButton):

 self._layout = favoritesview.RANDOM_LAYOUT

-# TRANS: label for the free layout in the favorites view
-menu_item = MenuItem(_('Free'), 'activity-start')
+# TRANS: label for the freeform layout in the favorites view
+menu_item = MenuItem(_('Freeform'), 'activity-start')
 menu_item.connect('activate', self.__layout_activate_cb,
   favoritesview.RANDOM_LAYOUT)
 self.props.palette.menu.append(menu_item)
--
___
Sugar mailing list
Sugar@lists.laptop.org
http://lists.laptop.org/listinfo/sugar


Re: [sugar] [PATCH] Rename Free view to Freeform view, for clarity

2008-06-20 Thread Marco Pesenti Gritti
r+

Please get this in ASAP so that I get it in 0.81.3 (string change)

Marco

On Sat, Jun 21, 2008 at 1:16 AM, Eben Eliason [EMAIL PROTECTED] wrote:
 This change was discussed at the design call today, and we felt it was
 worth slipping in.

 ---
  src/view/home/HomeBox.py |4 ++--
  1 files changed, 2 insertions(+), 2 deletions(-)

 diff --git a/src/view/home/HomeBox.py b/src/view/home/HomeBox.py
 index 61ceee9..46d2fbc 100644
 --- a/src/view/home/HomeBox.py
 +++ b/src/view/home/HomeBox.py
 @@ -207,8 +207,8 @@ class FavoritesButton(RadioToolButton):

 self._layout = favoritesview.RANDOM_LAYOUT

 -# TRANS: label for the free layout in the favorites view
 -menu_item = MenuItem(_('Free'), 'activity-start')
 +# TRANS: label for the freeform layout in the favorites view
 +menu_item = MenuItem(_('Freeform'), 'activity-start')
 menu_item.connect('activate', self.__layout_activate_cb,
   favoritesview.RANDOM_LAYOUT)
 self.props.palette.menu.append(menu_item)
 --
 ___
 Sugar mailing list
 Sugar@lists.laptop.org
 http://lists.laptop.org/listinfo/sugar

___
Sugar mailing list
Sugar@lists.laptop.org
http://lists.laptop.org/listinfo/sugar


Re: [sugar] feature freeze coming

2008-06-20 Thread Giannis Galanis
What is the decision on olpc-netutils?

It involves #7171, #7172, #7174
___
Sugar mailing list
Sugar@lists.laptop.org
http://lists.laptop.org/listinfo/sugar


Re: [sugar] feature freeze coming

2008-06-20 Thread Michael Stone
On Sat, Jun 21, 2008 at 01:54:07AM +0100, Giannis Galanis wrote:
 What is the decision on olpc-netutils?
 
 It involves #7171, #7172, #7174

Somebody needs to package them, no one has volunteered, and I haven't
gotten to it yet myself. Nothing more, nothing less.

Michael
___
Sugar mailing list
Sugar@lists.laptop.org
http://lists.laptop.org/listinfo/sugar


Re: [sugar] [PATCH] Add an option for choosing the layout in the favorites view.

2008-06-20 Thread Michael Stone
On Fri, Jun 20, 2008 at 06:27:33PM +0200, Marco Pesenti Gritti wrote:
 On Fri, Jun 20, 2008 at 6:24 PM, Tomeu Vizoso [EMAIL PROTECTED] wrote:
  On Fri, Jun 20, 2008 at 6:08 PM, Walter Bender [EMAIL PROTECTED] wrote:
  Is this done in a way such that it can be set by the customization key
  process? I can imagine that many groups will prefer the ring to random
  and want to make it an installation default.
 
  Not right now, but would be quite easy to add an option to the control
  panel and let customization keys change the stored preference.
 
 Even if not exposed in the cp UI we should at least have an hidden preference.
 We have no way right to customize sugar profiles but we should have one.
 
 Marco

I'm interested by the (implicit) idea that (all?) settings modifiable
through the control panel should also be customizable. However, as I
pointed out not long ago, some care needs to be taken to restrict the
ability of the customization process to violate our security principles.

As a strawman, how about using a convention or technology similar to

  http://thedjbway.org/daemontools/envdir.html

to record the key-value settings that make up the bulk of the
'customizable' features?

Michael
___
Sugar mailing list
Sugar@lists.laptop.org
http://lists.laptop.org/listinfo/sugar